package InsulinSignaling "A package for modeling insuling signaling in fat cells"
  package Components "Components used in the main model"
    extends Modelica.Icons.Package;

    model IR_feedback
      extends BioChem.Interfaces.Reactions.Uui;
      extends BioChem.Interfaces.Reactions.Modifiers.Activator;
      parameter Real kbasal = 1;
      parameter Real vmax = 1;
    equation
      rr = s1.c * (kbasal + vmax * a1.c / (1 + a1.c));
      annotation(Documentation(info = "", revisions = ""), Diagram(coordinateSystem(extent = {{-170.0, -105.0}, {170.0, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end IR_feedback;

    model IRS1_activation
      extends BioChem.Interfaces.Reactions.Uur;
      parameter Real kr = 1;
      parameter Real kf1 = 1;
      parameter Real kf2 = 1;
      BioChem.Interfaces.Nodes.ActivatorConnector a1 annotation(Placement(visible = true, transformation(origin = {30.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {30.0, 90.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)));
      BioChem.Interfaces.Nodes.ActivatorConnector a2 annotation(Placement(visible = true, transformation(origin = {-30.0, 70.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0), iconTransformation(origin = {-30.0, 90.0}, extent = {{-20.0, -20.0}, {20.0, 20.0}}, rotation = 0)));
    equation
      rr = s1.c * (kf1 * a1.c + kf2 * a2.c) - kr * p1.c;
      a1.r = 0;
      a2.r = 0;
      annotation(Documentation(info = "", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Line(visible = true, origin = {0.0, 3.75}, points = {{0.0, 56.25}, {0.0, 6.25}}, color = {0, 0, 255}, arrow = {Arrow.None, Arrow.Open}, arrowSize = 25)}), Diagram(coordinateSystem(extent = {{-170.0, -105.0}, {170.0, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})));
    end IRS1_activation;
    annotation(Documentation(info = "<html><!--WSMINSERTIONTAGSTART Components -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Insulin Signaling: Modeling a Biochemical Process</h1><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This subpackage contains components used in the <a href=\"modelica://InsulinSignaling.InsulinModel\">main model</a>.
</p><ul></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND Components --></html>", revisions = ""), Diagram(coordinateSystem(extent = {{-148.5, -105.0}, {148.5, 105.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
  end Components;

  model InsulinModel "Model of insulin signaling"
    extends BioChem.Compartments.ConstantCompartment(V.start = 1, mainCompartment = true);
    parameter Real insulinConcentration = 100;
    BioChem.Substances.Substance IRinsulin(c.unit = "a.u.", c.stateSelect = StateSelect.always) "Bound Insulin Receptor" annotation(Placement(visible = true, transformation(origin = {-80, 54.87}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    BioChem.Substances.Substance IRp(c.unit = "a.u.", c.stateSelect = StateSelect.always, c.start = 0.000326) "Phosphorylated Insulin Receptor" annotation(Placement(visible = true, transformation(origin = {-37.816, 60}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    BioChem.Reactions.MassAction.Irreversible.UniUni.Uui IRphosphorylation(k1 = 4.48) annotation(Placement(visible = true, transformation(origin = {-59.0095, 57.4881}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 6)));
    BioChem.Substances.SignalSubstance insulin(c.unit = "a.u.") "Signal Substance" annotation(Placement(visible = true, transformation(origin = {-136.864, 76.802}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    BioChem.Substances.Substance IR(c.unit = "a.u.", c.start = 100, n.start = 100, c.stateSelect = StateSelect.always) "Unphosphorylated Insulin Receptor" annotation(Placement(visible = true, transformation(origin = {-122.212, 46.626}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    BioChem.Reactions.MassAction.Reversible.UniUni.Uur basalphosphorylation(k1 = 0.2427355862, k2 = 70074) annotation(Placement(visible = true, transformation(origin = {-75.2375, 25.7005}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    BioChem.Substances.Substance IRpinternalized(c.unit = "a.u.", c.stateSelect = StateSelect.always, c.start = 1.15166) "Phosphorylated Internalized Insulin Receptor" annotation(Placement(visible = true, transformation(origin = {-35.815, -10}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    BioChem.Substances.Substance IRinternalized(c.unit = "a.u.", c.stateSelect = StateSelect.always, c.start = 0.0000274573117064578) "Unphosphorylated Internalized Insulin Receptor" annotation(Placement(visible = true, transformation(origin = {-107.154, -10}, extent = {{-10, 10}, {10, -10}}, rotation = 0)));
    BioChem.Reactions.MassAction.Irreversible.UniUni.Uui endocytosis(k1 = 3515) annotation(Placement(visible = true, transformation(origin = {-20.0, 20.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -90)));
    BioChem.Reactions.MassAction.Irreversible.UniUni.Uui recycling(k1 = 41769) annotation(Placement(visible = true, transformation(origin = {-136.4583, 14.652}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = -270)));
    InsulinSignaling.Components.IR_feedback IRdephosphorylation(kbasal = 0.034, vmax = 37) annotation(Placement(visible = true, transformation(origin = {-74.5375, -10.0}, extent = {{10.0, 10.0}, {-10.0, -10.0}}, rotation = 0)));
    BioChem.Substances.Substance IRS1p(c.unit = "a.u.", c.stateSelect = StateSelect.always, c.start = 0.7877) "Phosphorylated Insulin Receptor Substrate" annotation(Placement(visible = true, transformation(origin = {6.916, -27.145}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    BioChem.Substances.Substance IRS1(c.unit = "a.u.", c.start = 99, n.start = 100, c.stateSelect = StateSelect.always) "Unphosphorylated Insulin Receptor Substrate" annotation(Placement(visible = true, transformation(origin = {77.674, -27.145}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    BioChem.Substances.Substance X(c.unit = "a.u.", c.start = 99.97, n.start = 100, c.stateSelect = StateSelect.always) annotation(Placement(visible = true, transformation(origin = {4.8283, -68.37}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    BioChem.Substances.Substance Xactive(c.unit = "a.u.", c.stateSelect = StateSelect.always, c.start = 0.0265284) annotation(Placement(visible = true, transformation(origin = {-55.1717, -68.37}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 0)));
    BioChem.Reactions.MassAction.Reversible.UniUni.Uurfa Xactivation(k2 = 0.0812658755, k1 = 0.0000275772) annotation(Placement(visible = true, transformation(origin = {-25.1717, -68.37}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    InsulinSignaling.Components.IRS1_activation IRS1phosphorylation(kf1 = 0.765, kf2 = 3.32, kr = 149) annotation(Placement(visible = true, transformation(origin = {42.4405, -27.1451}, extent = {{10.0, -10.0}, {-10.0, 10.0}}, rotation = 0)));
    BioChem.Reactions.MassAction.Reversible.UniUni.Uurfa insulinBinding(k1 = 18047, k2 = 36569) annotation(Placement(visible = true, transformation(origin = {-101.7244, 50.0}, extent = {{-10.0, -10.0}, {10.0, 10.0}}, rotation = 11)));
  equation
    connect(recycling.p1, IR.n1) annotation(Line(visible = true, origin = {-132.897, 34.142}, points = {{-3.562, -8.24}, {-3.562, -0.516}, {-3.562, 12.484}, {10.685, 12.484}}, color = {0, 85, 127}, smooth = Smooth.Bezier));
    connect(IR.n1, insulinBinding.s1) annotation(Line(visible = true, origin = {-118.988, 46.932}, points = {{-3.223, -0.307}, {-3.223, -0.307}, {-3.223, -0.307}, {6.221, 0.921}}, color = {0, 85, 0}, smooth = Smooth.Bezier));
    connect(IR.n1, basalphosphorylation.s1) annotation(Line(visible = true, origin = {-115.439, 23.198}, points = {{-6.772, 23.427}, {-6.772, 2.502}, {28.952, 2.502}, {28.952, 2.502}}, color = {0, 85, 0}, smooth = Smooth.Bezier));
    connect(insulin.n1, insulinBinding.aF1) annotation(Line(visible = true, origin = {-114.582, 70.813}, points = {{-22.281, 5.989}, {11.141, 5.989}, {10.95, -10.996}}, color = {0, 85, 0}, pattern = LinePattern.Dash, smooth = Smooth.Bezier));
    connect(insulinBinding.p1, IRinsulin.n1) annotation(Line(visible = true, origin = {-83.56, 53.962}, points = {{-7.121, -1.815}, {3.56, 0.908}, {3.56, 0.908}}, color = {0, 85, 127}, smooth = Smooth.Bezier));
    connect(IRinsulin.n1, IRphosphorylation.s1) annotation(Line(visible = true, origin = {-66.958, 64.299}, points = {{-13.042, -9.43}, {-11.196, -7.048}, {-13.042, -9.399}, {-3.239, -7.987}}, color = {0, 85, 0}, smooth = Smooth.Bezier));
    connect(IRphosphorylation.p1, IRp.n1) annotation(Line(visible = true, origin = {-41.491, 60.139}, points = {{-6.33, -1.475}, {3.675, 0.046}, {3.675, 0.046}, {3.675, -0.139}}, color = {0, 85, 127}, smooth = Smooth.Bezier));
    connect(IRp.n1, endocytosis.s1) annotation(Line(visible = true, origin = {-20.786, 46.811}, points = {{-17.029, 13.189}, {0.786, 13.189}, {0.786, -12.502}, {0.786, -15.561}}, color = {0, 85, 0}, smooth = Smooth.Bezier));
    connect(IRp.n1, IRS1phosphorylation.a2) annotation(Line(visible = true, origin = {10.687, 29.908}, points = {{-48.503, 30.092}, {-32.207, 30.092}, {34.753, 30.092}, {34.753, -48.053}, {34.753, -48.053}}, color = {0, 85, 0}, pattern = LinePattern.Dash, smooth = Smooth.Bezier));
    connect(basalphosphorylation.p1, IRp.n1) annotation(Line(visible = true, origin = {-46.54, 37.134}, points = {{-17.448, -11.433}, {8.724, -11.433}, {8.724, 22.866}}, color = {0, 85, 127}, smooth = Smooth.Bezier));
    connect(endocytosis.p1, IRpinternalized.n1) annotation(Line(visible = true, origin = {-27.907, -5.312}, points = {{7.907, 14.062}, {7.907, -4.688}, {-7.907, -4.688}, {-7.907, -4.688}}, color = {0, 85, 127}, smooth = Smooth.Bezier));
    connect(Xactive.n1, IRdephosphorylation.a1) annotation(Line(visible = true, origin = {-64.8546, -37.3536}, points = {{9.6829, -31.0164}, {9.6829, 4.7895}, {-9.6829, 4.7895}, {-9.6829, 18.3536}}, color = {0, 85, 0}, pattern = LinePattern.Dash, smooth = Smooth.Bezier));
    connect(IRpinternalized.n1, IRdephosphorylation.s1) annotation(Line(visible = true, origin = {-49.551, -10}, points = {{13.736, 0}, {-13.736, 0}}, color = {0, 85, 0}));
    connect(IRdephosphorylation.p1, IRinternalized.n1) annotation(Line(visible = true, origin = {-96.471, -10}, points = {{10.683, 0}, {-10.683, 0}}, color = {0, 85, 127}));
    connect(IRinternalized.n1, recycling.s1) annotation(Line(visible = true, origin = {-126.69, -5.533}, points = {{19.536, -4.467}, {-9.768, -4.467}, {-9.768, 8.935}}, color = {0, 85, 0}, smooth = Smooth.Bezier));
    connect(IRpinternalized.n1, IRS1phosphorylation.a1) annotation(Line(visible = true, origin = {14.355, -12.715}, points = {{-50.17, 2.715}, {25.085, 2.715}, {25.085, -5.43}}, color = {0, 85, 0}, pattern = LinePattern.Dash, smooth = Smooth.Bezier));
    connect(IRS1p.n1, Xactivation.aF1) annotation(Line(visible = true, origin = {-9.128, -49.314}, points = {{16.044, 22.169}, {16.044, -6.056}, {-16.044, -6.056}, {-16.044, -9.056}}, color = {0, 85, 0}, pattern = LinePattern.Dash, smooth = Smooth.Bezier));
    connect(X.n1, Xactivation.s1) annotation(Line(visible = true, origin = {-4.5467, -68.37}, points = {{9.375, 0.0}, {-9.375, 0.0}}, color = {0, 85, 0}));
    connect(Xactivation.p1, Xactive.n1) annotation(Line(visible = true, origin = {-45.7967, -68.37}, points = {{9.375, 0.0}, {-9.375, 0.0}}, color = {0, 85, 127}));
    connect(IRS1phosphorylation.p1, IRS1p.n1) annotation(Line(visible = true, origin = {19.053, -27.145}, points = {{12.137, -0}, {-12.137, 0}}, color = {0, 85, 127}));
    connect(IRS1.n1, IRS1phosphorylation.s1) annotation(Line(visible = true, origin = {65.682, -27.145}, points = {{11.992, 0}, {-11.992, 0}}, color = {0, 85, 0}));
    insulin.c = insulinConcentration;
    annotation(experiment(StartTime = 0.0, StopTime = 30.0, NumberOfIntervals = -1, __Wolfram_Algorithm = "dassl", Tolerance = 0.000001, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(PlotSet(plots = {Plot(name = "InternalizedIRRates", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = endocytosis.rr, legend = "Endocytosis Rate"), Curve(x = time, y = IRdephosphorylation.rr, legend = "Internalized Insulin Receptor (IR) Dephosphorylation Rate"), Curve(x = time, y = recycling.rr, legend = "Recycling Rate"), Curve(x = time, y = IRS1phosphorylation.rr, legend = "Insulin Receptor Substrate (IRS) Phosphorylation Rate")})}), Plot(name = "IRS1Concentrations", subPlots = {SubPlot(curves = {Curve(x = time, y = IRS1p.c, legend = "Phosphorylated Insulin Receptor Substrate (IRS1p)"), Curve(x = time, y = IRS1.c, legend = "Unphosphorylated Insulin Receptor Substrate (IRS1)")})}), Plot(name = "InternalizedIRConcentrations", subPlots = {SubPlot(curves = {Curve(x = time, y = IRinternalized.c, legend = "Phosphorylated Internalized Insulin Receptor (IRp)"), Curve(x = time, y = IRpinternalized.c, legend = "Unphosphorylated Internalized Insulin Receptor (IR)")})}), Plot(name = "IRConcentrations", subPlots = {SubPlot(curves = {Curve(x = time, y = IRp.c, legend = "Phosphorylated Insulin Receptor (IRp)"), Curve(x = time, y = IR.c, legend = "Unphosphorylated Insulin Receptor (IR)"), Curve(x = time, y = IRinsulin.c, legend = "Bound Insulin Receptor (IR-Insulin)"), Curve(x = time, y = insulin.c, legend = "Insulin")})}), Plot(name = "PhosphorylationRates", subPlots = {SubPlot(curves = {Curve(x = time, y = basalphosphorylation.rr, legend = "Basal Phosphorylation"), Curve(x = time, y = insulinBinding.rr, legend = "Insulin Binding"), Curve(x = time, y = IRphosphorylation.rr, legend = "Bound Phosphyralation")}, range = Range(xmin = 0.126982, xmax = 30.0298, ymin = -1275.1, ymax = 1224.9))})})), preferredView = "info", Documentation(info = "<html><!--WSMINSERTIONTAGSTART ExampleModel -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Insulin Signaling: Modeling a Biochemical Process</h1><div class=\"contenttable\">
   <span class=\"contenttableheader\">CONTENTS:</span><br/>
   <table class=\"contenttabletable\"><tr><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Introduction').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Introduction</a></td><td><a href=\"#\" onClick=\"document.getElementById('headerTag_Analysis').scrollIntoView(); return false;\"><span class=\"hacek\">&#711;</span> Analysis</a></td></tr></table></div><a id=\"headerTag_Introduction\" class=\"target\">&nbsp;</a>
    <h2>Introduction</h2>
    <p class=\"\">
Insulin signaling in fat cells plays an important role in controlling the glucose level in the body. Insulin binding to receptors causes them to phosphorylate, transducing the insulin signal into the cells, controlling glucose uptake.
</p><p class=\"\">
In order to get the full experience of this example, you need the following:
</p><ul><li>A desktop Wolfram Language product; a free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></li><li>The <a href=\"InsulinSignaling.nb\">InsulinSignaling.nb</a> notebook that came in the same bundle as this model</li></ul><div class=\"mathematicapointerwrapper\">
   <div class=\"mathematicapointertop\">&nbsp;</div>
   <div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"InsulinSignaling.nb\">InsulinSignaling.nb</a>.
</p></div>
   </div><a id=\"headerTag_Analysis\" class=\"target\">&nbsp;</a>
    <h2>Analysis</h2>
    <p class=\"\">
Simulate the system's response to an insulin stimulation, with a number of different parameter sets found to be plausible:
</p><p class=\"\">
<img src=\"modelica://InsulinSignaling/DocumentationFiles/compSim.png\" alt=\"compSim\"/>
</p><p class=\"\">
Plot the sensitivity bounds for parameters in the system, showing how much the IRS1 phosphorylation is affected by changes in each parameter. Find the parameters with the largest influence:
</p><p class=\"\">
<img src=\"modelica://InsulinSignaling/DocumentationFiles/sensitivity.png\" alt=\"sensitivity\"/>
</p><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND ExampleModel --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100.0, -100.0}, {100.0, 100.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10})), Diagram(coordinateSystem(extent = {{-170.0, -110.0}, {110.0, 110.0}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Polygon(visible = true, origin = {-2.0496, 84.1949}, fillColor = {255, 255, 255}, fillPattern = FillPattern.Solid, points = {{-167.95, 25.805}, {-167.95, 25.805}, {112.0496, 25.805}, {112.0496, 25.8051}, {112.0496, -24.1949}, {112.0496, -24.1949}, {-0.6329, -4.1949}, {-167.95, -54.195}, {-167.95, -54.195}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {-0.0, -27.7778}, fillColor = {233, 247, 255}, fillPattern = FillPattern.Solid, points = {{-170.0, -82.222}, {110.0, -82.222}, {110.0, -82.2222}, {110.0, 67.7778}, {110.0, 67.7778}, {0.0, 97.778}, {-170.0, 57.778}, {-170.0, 57.778}, {-170.0, -82.222}}, smooth = Smooth.Bezier), Polygon(visible = true, origin = {-20.837, 55.055}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, points = {{-149.163, -5.055}, {-149.163, -5.055}, {-149.163, -25.055}, {-149.163, -25.055}, {20.837, 4.945}, {130.837, -15.055}, {130.837, -15.055}, {130.837, 4.945}, {130.837, 4.945}, {20.837, 24.945}}, smooth = Smooth.Bezier)}));
  end InsulinModel;
  annotation(preferredView = "info", uses(Modelica(version = "4.0.0")), __Wolfram(openClass = InsulinSignaling.InsulinModel, useDocumentationTemplate = false), Documentation(info = "<html><!--WSMINSERTIONTAGSTART InsulinSignalingPackage -->
   <head>
   <style type=\"text/css\">
   
  body {
   padding: 0px;
   margin: 0px;
  }
  
  a {
   color: #cf1d24;
  }
  
  a.target {
   padding-top: 40px;
   margin-top: -40px;
  }
  
  p {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
  }
  
  h1 {
   font-size: 30;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-top: 32px;
   margin-bottom: 15px;
   margin-right: 20px;
   padding-top: 0px;
  }
  
  h2 {
   font-size: 20;
   color: #cf1d24;
   font-weight: bold;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 5px;
   margin-bottom: 9px;
  }
  
  h3 {
   background: url('DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-size: 14px;
   font-family: helvetica;
   color: #4B4B4B;
   font-weight: bold;
   padding-left: 18px;
   margin-left: 20px;
   margin-right: 20px;
   margin-top: 12px;
   margin-bottom: 8px;
  }
  
  ul {
   font-family: arial;
   font-size: 13;
   margin: 9px 40px 5px 40px;
   padding-bottom: 0px;
   color: #555555;
   max-width: 800px;
   list-style-type: square;
  }
  
  li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  div.header {
   background: url('DocumentationFiles/WSMLogo.png') no-repeat 0 0;
   height: 96px;
   margin-top: 35px;
   background-color: #871613;
  }
  
  .headerspan {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   display: inline-block;
   height: 35px;
   color: gray;
   padding: 0px;
   margin: 0px;
   margin-left: 20px;
  }
  
  .headera {
   font-family: arial;
   text-decoration: none;
   font-size: 12px;
   font-weight: bold;
   padding: 0px;
   color: inherit;
   vertical-align: middle;
   margin: 0px;
  }
  
  .headerlinkdiv {
   background: black;
   padding: 0px;
   height: 35px;
   margin: 0px;
   position: fixed; top: 0px; left: 0px; width: 100%;
  }
  
  .contenttable {
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   border-top: 3px solid #cf1d24;
   background: #f9f9f9;
   max-width: 500px;
   margin: 15px 15px 0px 20px;
   padding: 6px 10px 3px 10px;
  }
  
  .contenttableheader {
   color: #a4a4a4;
   font-size: 14px;
   font-family: arial;
  }
  
  .contenttabletable {
   border: 0px solid #FFFFFF;
   padding: 0px;
   padding-left: 20px;
  }
  
  .contenttable tr td {
   padding: 3px;
   min-width: 200px;
  }
  
  .contenttable tr td a {
   color: #555555;
   text-decoration: none;
   font-size: 13px;
   font-family: arial;
  }
  
  .hacek {
   color: #cf1d24;
   font-size: 25px;
   font-weight: plain;
   vertical-align: -40%;
  }
  
  .mathematicapointerwrapper {
   border: 0px solid #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .mathematicapointertop {
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 4px;
  }
  
  .mathematicapointerdiv {
   background: url('./DocumentationFiles/mathematicabook.png') no-repeat  left center;
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px 9px 9px 89px;
   max-width: 500px;
   min-height: 67px;
  }
  
  p.mathematicapointer {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  .infoboxwrapper {
   border: 0px solid #DDDDDD;
   -webkit-box-shadow: 3px 3px 3px #DDDDDD;
   margin: 15px 15px 15px 40px;
   padding: 0px;
   max-width: 500px;
  }
  
  .infoboxtop {
   background: url('./DocumentationFiles/infotick.png') no-repeat left center;
   border: 1px solid #DDDDDD;
   background-color: #F2F2F2;
   padding: 0px;
   max-width: 500px;
   height: 37px;
  }
  
  div.infobox {
   border: 1px solid #DDDDDD;
   background-color: #FFFFFF;
   margin: 0px;
   padding: 15px;
   max-width: 500px;
  }
  
  p.infobox {
   padding: 0px;
   margin: 0px;
   font-size: 12px;
  }
  
  h2.legal {
   font-family: arial;
   font-size: 14;
   color: #cf1d24;
   margin: 15px 15px 15px 20px;
   font-weight: bold;
  }
  
  h3.legal {
   background: url('./DocumentationFiles/dingbat3.png') no-repeat 0 0;
   font-family: arial;
   font-size: 12;
   color: #808080;
   margin-left: 38px;
   padding-left: 12px;
   font-weight: bold;
  }
  
  ul.legal {
   font-size: 10px;
   font-family: arial;
   color: #555555;
   margin-left: 28px;
  }
  
  ul.legal li {
   margin-left: 0px;
   margin-top: 4px;
   margin-bottom: 2px;
   padding-left: 0px;
  }

  ul.imgbullets li {
   margin-left: -40px;
   margin-top: 4px;
   margin-bottom: 10px;
   padding-left: 30px;
   list-style-type: none;
  }
  
  p.legallarge {
   font-size: 12px;
   margin-left: 38px;
  }
  
  p.legalsmall {
   font-size: 11px;
   margin-left: 38px;
   padding-left: 12px;
  }
  
  .legalend {
   height: 10px;
  }
  
  .variablename {
   font-family: Courier New, Courier;
  }
  
  .dialogelement {
   font-weight: bold;
  }
  
  .menuitem {
   font-weight: bold;
  }
  
  .mr {
   font-family: Courier New, Courier;
  }
  
  .ttable {
	border-collapse: collapse;
    width: 100%;
	}

	.ttable td, th {
    border: 1px solid #dddddd;
    text-align: left;
	padding: 8px;
	}

	.ttable tr:nth-child(even) {
		background-color: #dddddd;
	}
  
   </style>
   </head>
   <body>
   
  <div class=\"headerlinkdiv\">
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/examples.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/examples_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/examples.png) no-repeat 0 0';
   \"><a href=\"https://www.wolfram.com/system-modeler/examples/\" class=\"headera\">More Examples</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/video.png) no-repeat 0 0;
   padding-left: 29px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/video_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/video.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/resources/get-started/\" class=\"headera\">Introductory Videos</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/docs.png) no-repeat 0 0;
   padding-left: 20px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/docs_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/docs.png) no-repeat 0 0';
   \"><a href=\"http://reference.wolfram.com/system-modeler\" class=\"headera\">Documentation</a></span>
  
   <span class=\"headerspan\" style=\"background: url(DocumentationFiles/contact.png) no-repeat 0 0;
   padding-left: 24px;
   \"
   onmouseover=\"
   	this.style.color = 'white';
   	this.style.background = 'url(DocumentationFiles/contact_active.png) no-repeat 0 0';
   \"
   onmouseout=\"
   	this.style.color = 'gray';
   	this.style.background = 'url(DocumentationFiles/contact.png) no-repeat 0 0';
   \"><a href=\"http://www.wolfram.com/system-modeler/contact-us/\" class=\"headera\">Contact Us</a></span>
  </div> <div class=\"header\">&nbsp;</div> <h1>Insulin Signaling: Modeling a Biochemical Process</h1><p class=\"\">
In order to get the full experience of this example, you need the following:
</p><ul><li>A desktop Wolfram Language product; a free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></li><li>The <a href=\"InsulinSignaling.nb\">InsulinSignaling.nb</a> notebook that came in the same bundle as this model</li></ul><div class=\"mathematicapointerwrapper\">
   <div class=\"mathematicapointertop\">&nbsp;</div>
   <div class=\"mathematicapointerdiv\"><p class=\"mathematicapointer\">
These pages show an overview of the example. For the full example, open the accompanying notebook <a href=\"InsulinSignaling.nb\">InsulinSignaling.nb</a>.
</p></div>
   </div><a id=\"headerTag_PackageOverview\" class=\"target\">&nbsp;</a>
    <h2>Package Overview</h2>
    <p class=\"\">
This package contains a model of insulin signaling, and a package of custom components used in the model:
</p><ul><li><a href=\"modelica://InsulinSignaling.InsulinModel#diagram\">InsulinModel</a>: the main model of the insulin signaling (<a href=\"modelica://InsulinSignaling.InsulinModel\">show documentation</a>)</li><li><a href=\"modelica://InsulinSignaling.Components#info\">Components</a>: a package containing custom components used in the main model</li></ul><h2 class=\"legal\"> <a href=\"#\" onclick=\"
   if(document.getElementById('legalSection').style.display == 'none'){
   document.getElementById('legalSection').style.display = 'block';
   document.getElementById('showlegalSection').style.display = 'none';
   document.getElementById('hidelegalSection').style.display = 'inline';
   } else {
   document.getElementById('legalSection').style.display = 'none';
   document.getElementById('showlegalSection').style.display = 'inline';
   document.getElementById('hidelegalSection').style.display = 'none';
   };
   return false;\" style=\"text-decoration: inherit; color: inherit\"><img src=\"./DocumentationFiles/showhide2.png\" alt=\"Show\" id=\"showlegalSection\" style=\"display: inline; vertical-align: text-bottom;\" /><img src=\"./DocumentationFiles/showhide.png\" alt=\"Hide\" id=\"hidelegalSection\" style=\"display: none; vertical-align: text-bottom;\" />Terms and Conditions of Use</a> </h2>
    <span id=\"legalSection\" style=\"display: none;\"><p class=\"legallarge\">
This domain example is an informational resource made freely available by Wolfram Research.
</p><h3 class=\"legal\">Use of This Example</h3>
    <span id=\"legalSection\" style=\"display: block;\"><ul class=\"legal\"><li>You may not use this example for any purpose that is unlawful or dangerous.</li><li>You assume total responsibility and risk for your use of this example.</li><li>You may not present this example with any alteration to its trade dress, trademarks, or design.</li></ul></span><h3 class=\"legal\">License</h3>
    <span id=\"legalSection\" style=\"display: block;\"><p class=\"legalsmall\">
All content in this bundle is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License. By accessing the content or using it in any way, you accept and agree to be bound by the terms of this license. If you do not agree to these Terms of Use, you may not use this content. Wolfram Research reserves the right to change, modify, add to, or remove portions of these Terms of Use at any time without notice. Please refer back to <a href=\"http://www.wolfram.com\">www.wolfram.com</a> for the latest Terms of Use.
</p><p class=\"legalsmall\">
A summary of the licensing terms can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0\">http://creativecommons.org/licenses/by-nc-sa/3.0</a>
</p><p class=\"legalsmall\">
The full legal code can be found at:<br>
        <a href=\"http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode\">http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode</a>
</p></span></span><div class=\"legalend\">&nbsp;</div>
   </body>
   <!--WSMINSERTIONTAGEND InsulinSignalingPackage --></html>", revisions = ""), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}));
end InsulinSignaling;
